.. _user:

################
NumPy User Guide
################

This guide is intended as an introductory overview of NumPy and
explains how to install and make use of the most important features of
NumPy. For detailed reference documentation of the functions and
classes contained in the package, see the :ref:`reference`.

.. warning::

   This "User Guide" is still a work in progress; some of the material
   is not organized, and several aspects of NumPy are not yet covered
   sufficient detail.  We are an open source community continually
   working to improve the documentation and eagerly encourage interested
   parties to contribute.  For information on how to do so, please visit
   the NumPy `doc wiki <http://docs.scipy.org/numpy/Front%20Page>`_.

   More documentation for NumPy can be found on the `numpy.org
   <http://www.numpy.org>`__ website.

   Thanks!

.. toctree::
   :maxdepth: 2

   introduction
   basics
   performance
   misc
   c-info
